@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 import torch
 from typing import Optional
 from torch import nn, Tensor
@@ -14,20 +16,16 @@ class WeberNegation(BaseNegation):
             assert default_p > -1
             self.p = nn.Parameter(torch.tensor(default_p))
         assert len(self.p.shape) == 0
-
         self.relu = torch.nn.ReLU()
         self.eps = 0.01
+        self.__name__ = 'Weber'
 
     def __call__(self,
                  a: Tensor) -> Tensor:
-
-        res: Optional[Tensor] = None
-
-        self.p = self.relu(self.p) - 1
+        
+        self.p.data = self.relu(self.p.data + 1) - 1
 
         if self.p == -1:
-            self.p += self.eps
-
+            self.p.data += self.eps
         res = (1.0 - a) / (1.0 + self.p * a)
-
         return res
