@@ -17,25 +17,15 @@ class DombiTCoNorm(BaseTCoNorm):
         if self.p is None:
             self.p = nn.Parameter(torch.tensor(default_p))
 
-
         assert len(self.p.shape) == 0
 
         self.relu = torch.nn.ReLU()
         self.eps = 0.001
 
-
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
-
-            res: Optional[Tensor] = None
-
-
-            if self.p == 0:
-                self.p += self.eps # eps is added to avoid 0
-
-
-            res = 1.0 - (((1-a) * (1-b)) / torch.maximum(torch.maximum(1.0 - a, 1.0 - b), self.p))
-
-
-            return res
+        if self.p == 0:
+            self.p.data += self.eps # eps is added to avoid 0
+        res = 1.0 - (((1 - a) * (1 - b)) / torch.maximum(torch.maximum(1.0 - a, 1.0 - b), self.p))
+        return res
