@@ -23,14 +23,10 @@ class DuboisTCoNorm(BaseTCoNorm):
 
         assert len(self.p.shape) == 0
 
-
-
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
-
-            res: Optional[Tensor] = None
-            self.p = torch.clamp(res, min = 0, max = 1)
+            self.p.data = torch.clamp(self.p.data, min=0, max=1)
 
             p_1 = a + b
             p_2 = p_1 + (self.p * a * b)
