@@ -17,7 +17,6 @@ class SchweizerSklarTCoNorm(BaseTCoNorm):
         if self.p is None:
             self.p = nn.Parameter(torch.tensor(default_p))
 
-
         assert len(self.p.shape) == 0
 
         self.eps += 0.001
@@ -25,11 +24,8 @@ class SchweizerSklarTCoNorm(BaseTCoNorm):
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
-
-            res: Optional[Tensor] = None
-
             if self.p == 0:
-                self.p += self.eps
+                self.p.data += self.eps
 
             p_1 = torch.pow(1.0 - a, self.p)
             p_2 = torch.pow(1.0 - b, self.p)
