@@ -32,7 +32,7 @@ class WeberTCoNorm(BaseTCoNorm):
 
             res: Optional[Tensor] = None
 
-            self.p = self.relu(self.p) - 1
+            self.p = self.relu(self.p + 1) - 1
 
             p_1 = a + b
             p_2 = p_1 + (self.p * a * b)
