@@ -29,13 +29,13 @@ class AczelAlsinaTNorm(BaseTNorm):
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
-        res: Optional[Tensor] = None
-
+        self.p.data = self.relu(self.p.data)
         if self.p == 0:
-            self.p += self.eps
+            self.p.data += self.eps
 
+        #Taking the log here might be problamitc as some scores might be explicit 0's
+        # Maybe we need to ofset by a small eps. i.e. 10^-4 ?
         p_1 = torch.pow(torch.abs(torch.log(a)), self.p)
         p_2 = torch.pow(torch.abs(torch.log(b)), self.p)
         res = torch.exp(-torch.pow(p_1 + p_2, 1.0 / self.p))
-
         return res
