@@ -20,20 +20,18 @@ class DombiTNorm(BaseTNorm):
         self.relu = torch.nn.ReLU()
         self.eps = 0.001
 
-
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
-        res: Optional[Tensor] = None
-
-        self.p = self.relu(self.p)
+        self.p.data = self.relu(self.p.data)
 
         if self.p == 0:
-            self.p += self.eps # eps is added to avoid 0
+            # eps is added to avoid 0
+            self.p.data += self.eps
 
-        p_1 = torch.pow((1-a)/a , self.p)
-        p_2 = torch.pow((1-b)/b, self.p)
-        p_3 = 1.0 + torch.pow(p_1 + p_2, 1.0/self.p)
+        p_1 = torch.pow((1 - a) / a, self.p)
+        p_2 = torch.pow((1 - b) / b, self.p)
+        p_3 = 1.0 + torch.pow(p_1 + p_2, 1.0 / self.p)
         res = 1.0 / p_3
 
         return res
