@@ -18,14 +18,10 @@ class DuboisTNorm(BaseTNorm):
             self.p = nn.Parameter(torch.tensor(default_p))
         assert len(self.p.shape) == 0
 
-
-
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
-        res: Optional[Tensor] = None
-
-        self.p = torch.clamp(res, min = 0, max = 1)
-        res = (a * b) / torch.maximum(torch.maximum(a,b), self.p)
+        self.p.data = torch.clamp(self.p.data, min=0, max=1)
+        res = (a * b) / torch.maximum(torch.maximum(a, b), self.p)
 
         return res
