@@ -24,18 +24,15 @@ class FrankTNorm(BaseTNorm):
     def __call__(self,
                  a: Tensor,
                  b: Tensor) -> Tensor:
-
-        res: Optional[Tensor] = None
-
-        self.p = self.relu(self.p)
+        self.p.data = self.relu(self.p.data)
 
         if self.p == 0 or self.p == 1:
-            self.p += self.eps
+            self.p.data += self.eps
 
         res =  1.0 + ((torch.pow(self.p,a) -1 ) * (torch.pow(self.p,b) - 1 ) / (self.p - 1.0))
         res = torch.log(res)
 
-        #log base change trick -> change base to p
+        # log base change trick -> change base to p
         res = res / torch.log(self.p)
 
         return res
