@@ -11,7 +11,7 @@ from typing import Optional
 class SchweizerSklarTNorm(BaseTNorm):
     def __init__(self,
                  p: Optional[Tensor] = None,
-                 default_p: float = 1.0) -> None:
+                 default_p: float = 0.1) -> None:
         super().__init__()
         self.p = p
         if self.p is None:
@@ -25,19 +25,26 @@ class SchweizerSklarTNorm(BaseTNorm):
                  a: Tensor,
                  b: Tensor) -> Tensor:
         res: Optional[Tensor] = None
+        # Careful that the value of parametr p can be 10e-8, thus maybe add eps.
 
+        self.p.data = self.relu(self.p.data)
         if self.p == 0:
-            self.p += self.eps
+            self.p.data += self.eps
 
-        if self.p.item() < 0.0:
-            res: Tensor = (a ** self.p + b ** self.p - 1.0) ** (1.0 / self.p)
-        elif self.p.item() == 0.0:
-            res: Tensor = a * b
-        elif self.p.item() > 0.0:
-            res: Tensor = (a ** self.p + b ** self.p - 1.0)
-            res: Tensor = torch.max(res, torch.tensor(0.0))
-            res: Tensor = res ** (1.0 / self.p)
+        # self.p.data = torch.clamp(self.p.data, min=-4)
+        if torch.isnan(self.p):
+            print("NAN a BRAT")
+            self.p.data = torch.tensor(0.1)
 
-        assert res is not None
+
+        res = (a ** self.p + b ** self.p) - 1.0
+        res = torch.maximum(res, torch.tensor(0.0))
+        res = res ** (1.0 / self.p)
+
+
+        if torch.sum(torch.isnan(res)):
+            print(self.p)
+            print(res)
+            print("GANDON NAN")
 
         return res
