@@ -30,7 +30,7 @@ class WeberTNorm(BaseTNorm):
                  b: Tensor) -> Tensor:
         res: Optional[Tensor] = None
 
-        self.p = self.relu(self.p) - 1
+        self.p.data = self.relu(self.p.data + 1) - 1
 
         p_1 = (1.0 + self.p) * ( a + b - 1.0)
         p_2 = p_1 - self.p * a * b
