@@ -27,9 +27,9 @@ class YagerTNorm(BaseTNorm):
         res: Optional[Tensor] = None
 
 
-        self.p = self.relu(self.p)
+        self.p.data = self.relu(self.p.data)
         if self.p == 0:
-            self.p += self.eps
+            self.p.data += self.eps
 
         p_1 = torch.pow(1.0 - a, self.p)
         p_2 = torch.pow(1.0 - b, self.p)
